@@ -26,6 +26,19 @@ def test_user_model():
     assert repr(user) == '<User meh>'
 
 
+def test_user_model_to_dict():
+    db = SQLAlchemy('sqlite:///:memory:')
+    auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
+    User = auth.User
+    db.create_all()
+    user = User(login=u'meh', password='foobar')
+    db.session.add(user)
+    db.commit()
+
+    user_dict = user.to_dict()
+    assert user_dict
+
+
 def test_backwards_compatibility():
     db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db)
@@ -50,10 +63,10 @@ def test_user_model_methods():
     db.commit()
 
     assert User.by_id(user.id) == user
-    assert User.by_id(33) == None
+    assert User.by_id(33) is None
 
     assert User.by_login(u'meh') == user
-    assert User.by_login(u'foobar') == None
+    assert User.by_login(u'foobar') is None
 
     assert user.has_password('foobar')
     assert not user.has_password('abracadabra')
@@ -89,6 +102,19 @@ def test_role_model():
     assert repr(role) == '<Role admin>'
 
 
+def test_role_model_to_dict():
+    db = SQLAlchemy('sqlite:///:memory:')
+    auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
+    Role = auth.Role
+    db.create_all()
+    role = Role(name=u'admin')
+    db.session.add(role)
+    db.commit()
+
+    role_dict = role.to_dict()
+    assert role_dict
+
+
 def test_role_model_methods():
     db = SQLAlchemy('sqlite:///:memory:')
     auth = authcode.Auth(SECRET_KEY, db=db, roles=True)
@@ -99,10 +125,10 @@ def test_role_model_methods():
     db.commit()
 
     assert Role.by_id(role.id) == role
-    assert Role.by_id(33) == None
+    assert Role.by_id(33) is None
 
     assert Role.by_name(u'admin') == role
-    assert Role.by_name(u'foobar') == None
+    assert Role.by_name(u'foobar') is None
 
     assert Role.get_or_create(u'admin') == role
 
@@ -250,10 +276,10 @@ def test_naked_sqlalchemy():
     db.session.commit()
 
     assert User.by_id(user.id) == user
-    assert User.by_id(33) == None
+    assert User.by_id(33) is None
 
     assert User.by_login(u'meh') == user
-    assert User.by_login(u'foobar') == None
+    assert User.by_login(u'foobar') is None
 
     assert user.has_password('foobar')
     assert not user.has_password('abracadabra')
